akhdefo_functions.Akhdefo_resample — akhdefo 2023 documentation

# akhdefo_functions.Akhdefo_resample

akhdefo_functions.Akhdefo_resample(input_raster='', output_raster='', xres=3.125, yres=3.125, SavFig=False, convert_units=False)

  This program performs raster resampling for multiple rasters

  Inputs:

  input_raster=””,

  output_raster=”” ,

  xres=3.125 ,

  yres=3.125,

  SavFig=False

  convert_units=False if True converts raster value units from m to mm

  Returns: Raster geotif